==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video transkripcija vyksta. Užverti langele?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Atverti folderį
</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai
</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra
</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotografija
</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video
</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Pakeisti kamerą
</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti
</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Užverti
</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti
</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti
</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti folderį
</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti
</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Neturiate leidimo veikti šiuo folderiu
</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Užverti
</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti folderį
</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai
</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Pagrindinė
</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Failo vieta
</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Rašyti
</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Žiūrovos režimas
</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Sveikinimo trukmė
</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Išvestis
</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Išvesties formatas
</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pc
</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pc
</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kameras</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kameras yra vaizdo ir video užklausos priemonė, kuri naudoja Jūsų PC kamerą ar webkamera.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation> failas nebuvo išsaugotas</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Vaizdas:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nustatymai apie resoliuciją</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Vaizdai:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Garsieji efektiškai</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Skritulio režimas</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Sklyptuvas</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Rėžių linijos</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 linijos</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 linijos</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Nors didžiausioje resoliucijoje:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kameras</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stabite įrašymą</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Atidaryti</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pagalba</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rodyti įspūdžius</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stošis nuo vaizdo įrašymo</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstinis meniu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stošis nuo vaizdo įrašymo</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalus</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Ilguma</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Gretas</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kaltas</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filmas</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grizlas</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Balti ir raudonai</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Ilguma</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Išeinantis</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Išjungtas</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Pratęsti vaizdo įrašymą</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtras</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Išvaizdos išvaizda</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenorėjęs webkameros</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webkamera yra naudojama</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Stabite įrašymą</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video transkripcija vyksta. Užverti langele?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Atverti folderį
</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai
</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra
</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotografija
</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video
</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Pakeisti kamerą
</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti
</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Užverti
</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti
</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti
</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti folderį
</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti
</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Neturiate leidimo veikti šiuo folderiu
</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Užverti
</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Neteisingas aplankas</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti folderį
</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai
</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Pagrindinė
</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Failo vieta
</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Rašyti
</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Žiūrovos režimas
</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Sveikinimo trukmė
</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Išvestis
</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Išvesties formatas
</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pc
</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pc
</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kameras</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kameras yra vaizdo ir video užklausos priemonė, kuri naudoja Jūsų PC kamerą ar webkamera.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation> failas nebuvo išsaugotas</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Išsaugoti į:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Vaizdas:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nustatymai apie resoliuciją</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Raiškė:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Vaizdai:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Garsieji efektiškai</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Skritulio režimas</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Sklyptuvas</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Rėžių linijos</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 linijos</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 linijos</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Nors didžiausioje resoliucijoje:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kameras</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stabite įrašymą</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Atidaryti</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pagalba</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rodyti įspūdžius</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stošis nuo vaizdo įrašymo</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstinis meniu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Fotografuoti</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Įrašyti vaizdo įrašą</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stošis nuo vaizdo įrašymo</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalus</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Ilguma</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Gretas</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kaltas</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filmas</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grizlas</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Balti ir raudonai</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Ilguma</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Išeinantis</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Išjungtas</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Pratęsti vaizdo įrašymą</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtras</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Išvaizdos išvaizda</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenorėjęs webkameros</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webkamera yra naudojama</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Stabite įrašymą</translation>
    </message>
</context>
</TS>
